@@ -16,7 +16,7 @@
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.  '''
 
-__version__ = "0.3.02"
+__version__ = "0.3.03"
 __author__ = "nagev"
 __license__ = "GPLv3"
 
@@ -32,40 +32,39 @@ def _decrypt_signature(s):
     # This function taken from youtube-dl source. Thanks!
     if len(s) == 92:
         return s[25] + s[3:25] + s[0] + s[26:42] + s[79] + s[43:79] + s[91] + \
-                s[80:83]
+            s[80:83]
     elif len(s) == 90:
         return s[25] + s[3:25] + s[2] + s[26:40] + s[77] + s[41:77] + s[89] \
-                + s[78:81]
+            + s[78:81]
     elif len(s) == 89:
         return s[84:78:-1] + s[87] + s[77:60:-1] + s[0] + s[59:3:-1]
     elif len(s) == 88:
-        return s[48] + s[81:67:-1] + s[82] + s[66:62:-1] + s[85] + \
-                s[61:48:-1] + s[67] + s[47:12:-1] + s[3] + s[11:3:-1] + s[2] \
-                + s[12]
+        return s[7:28] + s[87] + s[29:45] + s[55] + s[46:55] + s[2] +\
+            s[56:87] + s[28]
     elif len(s) == 87:
         return s[6:27] + s[4] + s[28:39] + s[27] + s[40:59] + s[2] + s[60:] 
     elif len(s) == 86:
         return s[5:40] + s[3] + s[41:48] + s[0] + s[49:86]
     elif len(s) == 85:
         return s[83:34:-1] + s[0] + s[33:27:-1] + s[3] + s[26:19:-1] + s[34]\
-                + s[18:3:-1] + s[27]
+            + s[18:3:-1] + s[27]
     elif len(s) == 84:
         return s[5:40] + s[3] + s[41:48] + s[0] + s[49:84]
     elif len(s) == 83:
         return s[81:64:-1] + s[82] + s[63:52:-1] + s[45] + s[51:45:-1] + s[1]\
-                + s[44:1:-1] + s[0]
+            + s[44:1:-1] + s[0]
     elif len(s) == 82:
         return s[1:19] + s[0] + s[20:68] + s[19] + s[69:82]
     elif len(s) == 81:
-        return s[56] + s[79:56:-1] + s[41] + s[55:41:-1] + s[80] + \
-                s[40:34:-1] + s[0] + s[33:29:-1] + s[34] + s[28:9:-1] + \
-                s[29] + s[8:0:-1] + s[9]
+        return s[56] + s[79:56:-1] + s[41] + s[55:41:-1] + s[80] \
+            +s[40:34:-1] + s[0] + s[33:29:-1] + s[34] + s[28:9:-1] + s[29] +\
+            s[8:0:-1] + s[9]
     elif len(s) == 80:
         return s[1:19] + s[0] + s[20:68] + s[19] + s[69:80]
     elif len(s) == 79:
         return s[54] + s[77:54:-1] + s[39] + s[53:39:-1] + s[78] + \
-                s[38:34:-1] + s[0] + s[33:29:-1] + s[34] + s[28:9:-1] + \
-                s[29] + s[8:0:-1] + s[9]
+            s[38:34:-1] + s[0] + s[33:29:-1] + s[34] + s[28:9:-1] + \
+            s[29] + s[8:0:-1] + s[9]
     else:
         raise NameError("Unable to decode video url - sig len %s" % len(s))
 
@@ -111,7 +110,7 @@ class Stream():
         print u"-Downloading '{}' [{:,} Bytes]".format(self.filename, total)
         status_string = ('  {:,} Bytes [{:.2%}] received. Rate: [{:4.0f} '
                          'kbps].  ETA: [{:.0f} secs]')
-        chunksize, bytesdone, t0 = 16834, 0, time.time()
+        chunksize, bytesdone, t0 = 1024, 0, time.time()
         outfh = open(filepath or self.filename, 'wb')
         while 1:
             chunk = response.read(chunksize)
